# img_pipe
![alt text](https://github.com/ChangLabUcsf/img_pipe/raw/master/icons/leftbrain_blackbg.png "img_pipe") Image processing pipeline for ECoG data

Developed by Liberty Hamilton, David Chang, Morgan Lee

This contains the imaging pipeline as one importable python class for running a patient's
brain surface reconstruction and electrode localization/labeling.

To download this package, either clone this repository and run <b>python setup.py</b> or run <b>pip install img_pipe</b> from the terminal. 

